summaryrefslogtreecommitdiff
path: root/mpn/mips3
diff options
context:
space:
mode:
authorKevin Ryde <user42@zip.com.au>2000-04-16 01:20:01 +0200
committerKevin Ryde <user42@zip.com.au>2000-04-16 01:20:01 +0200
commit92a17b1594132bf5f8c7f9782d85ad5b5bb2eba8 (patch)
treed19a83c2fa5195c6d7c22903719653db1020fd83 /mpn/mips3
parent119565df1ef96a64307d86f42b1925baecabb85d (diff)
downloadgmp-92a17b1594132bf5f8c7f9782d85ad5b5bb2eba8.tar.gz
Change __mpn to __gmpn.
Diffstat (limited to 'mpn/mips3')
-rw-r--r--mpn/mips3/add_n.s10
-rw-r--r--mpn/mips3/addmul_1.s10
-rw-r--r--mpn/mips3/lshift.s10
-rw-r--r--mpn/mips3/mul_1.s10
-rw-r--r--mpn/mips3/rshift.s10
-rw-r--r--mpn/mips3/sub_n.s10
-rw-r--r--mpn/mips3/submul_1.s10
7 files changed, 35 insertions, 35 deletions
diff --git a/mpn/mips3/lshift.s b/mpn/mips3/lshift.s
index 324a6020c..5acee84d2 100644
--- a/mpn/mips3/lshift.s
+++ b/mpn/mips3/lshift.s
@@ -1,4 +1,4 @@
- # MIPS3 __mpn_lshift --
+ # MIPS3 __gmpn_lshift --
# Copyright (C) 1995 Free Software Foundation, Inc.
@@ -28,9 +28,9 @@
.text
.align 2
- .globl __mpn_lshift
- .ent __mpn_lshift
-__mpn_lshift:
+ .globl __gmpn_lshift
+ .ent __gmpn_lshift
+__gmpn_lshift:
.set noreorder
.set nomacro
@@ -92,4 +92,4 @@ __mpn_lshift:
.Lend: dsll $8,$10,$7
j $31
sd $8,-8($4)
- .end __mpn_lshift
+ .end __gmpn_lshift
diff --git a/mpn/mips3/rshift.s b/mpn/mips3/rshift.s
index 9920e1a9e..1568969b4 100644
--- a/mpn/mips3/rshift.s
+++ b/mpn/mips3/rshift.s
@@ -1,4 +1,4 @@
- # MIPS3 __mpn_rshift --
+ # MIPS3 __gmpn_rshift --
# Copyright (C) 1995 Free Software Foundation, Inc.
@@ -28,9 +28,9 @@
.text
.align 2
- .globl __mpn_rshift
- .ent __mpn_rshift
-__mpn_rshift:
+ .globl __gmpn_rshift
+ .ent __gmpn_rshift
+__gmpn_rshift:
.set noreorder
.set nomacro
@@ -89,4 +89,4 @@ __mpn_rshift:
.Lend: dsrl $8,$10,$7
j $31
sd $8,0($4)
- .end __mpn_rshift
+ .end __gmpn_rshift
diff --git a/mpn/mips3/add_n.s b/mpn/mips3/add_n.s
index 996a449eb..ab60c1072 100644
--- a/mpn/mips3/add_n.s
+++ b/mpn/mips3/add_n.s
@@ -1,4 +1,4 @@
# MIPS3 __mpn_add_n -- Add two limb vectors of the same length > 0 and
# store sum in a third limb vector.
# Copyright (C) 1995 Free Software Foundation, Inc.
@@ -29,9 +29,9 @@
.text
.align 2
- .globl __mpn_add_n
- .ent __mpn_add_n
-__mpn_add_n:
+ .globl __gmpn_add_n
+ .ent __gmpn_add_n
+__gmpn_add_n:
.set noreorder
.set nomacro
@@ -117,4 +117,4 @@ __mpn_add_n:
j $31
or $2,$2,$8
- .end __mpn_add_n
+ .end __gmpn_add_n
@@ -1,4 +1,4 @@
- # MIPS3 __mpn_add_n -- Add two limb vectors of the same length > 0 and
+ # MIPS3 __gmpn_add_n -- Add two limb vectors of the same length > 0 and
# store sum in a third limb vector.
# Copyright (C) 1995 Free Software Foundation, Inc.
diff --git a/mpn/mips3/addmul_1.s b/mpn/mips3/addmul_1.s
index cd75c1801..2ecf830fe 100644
--- a/mpn/mips3/addmul_1.s
+++ b/mpn/mips3/addmul_1.s
@@ -1,4 +1,4 @@
# MIPS3 __mpn_addmul_1 -- Multiply a limb vector with a single limb and
# add the product to a second limb vector.
# Copyright (C) 1992, 1994, 1995 Free Software Foundation, Inc.
@@ -29,9 +29,9 @@
.text
.align 4
- .globl __mpn_addmul_1
- .ent __mpn_addmul_1
-__mpn_addmul_1:
+ .globl __gmpn_addmul_1
+ .ent __gmpn_addmul_1
+__gmpn_addmul_1:
.set noreorder
.set nomacro
@@ -94,4 +94,4 @@ $LC0: ld $10,0($4)
j $31
daddu $2,$9,$2 # add high product limb and carry from addition
- .end __mpn_addmul_1
+ .end __gmpn_addmul_1
@@ -1,4 +1,4 @@
- # MIPS3 __mpn_addmul_1 -- Multiply a limb vector with a single limb and
+ # MIPS3 __gmpn_addmul_1 -- Multiply a limb vector with a single limb and
# add the product to a second limb vector.
# Copyright (C) 1992, 1994, 1995 Free Software Foundation, Inc.
diff --git a/mpn/mips3/mul_1.s b/mpn/mips3/mul_1.s
index 281d0574a..9d71c469b 100644
--- a/mpn/mips3/mul_1.s
+++ b/mpn/mips3/mul_1.s
@@ -1,4 +1,4 @@
# MIPS3 __mpn_mul_1 -- Multiply a limb vector with a single limb and
# store the product in a second limb vector.
# Copyright (C) 1992, 1994, 1995 Free Software Foundation, Inc.
@@ -29,9 +29,9 @@
.text
.align 4
- .globl __mpn_mul_1
- .ent __mpn_mul_1
-__mpn_mul_1:
+ .globl __gmpn_mul_1
+ .ent __gmpn_mul_1
+__gmpn_mul_1:
.set noreorder
.set nomacro
@@ -82,4 +82,4 @@ $LC0: mflo $10
j $31
daddu $2,$9,$2 # add high product limb and carry from addition
- .end __mpn_mul_1
+ .end __gmpn_mul_1
@@ -1,4 +1,4 @@
- # MIPS3 __mpn_mul_1 -- Multiply a limb vector with a single limb and
+ # MIPS3 __gmpn_mul_1 -- Multiply a limb vector with a single limb and
# store the product in a second limb vector.
# Copyright (C) 1992, 1994, 1995 Free Software Foundation, Inc.
diff --git a/mpn/mips3/sub_n.s b/mpn/mips3/sub_n.s
index 56c77d8bc..366b3b014 100644
--- a/mpn/mips3/sub_n.s
+++ b/mpn/mips3/sub_n.s
@@ -1,4 +1,4 @@
# MIPS3 __mpn_sub_n -- Subtract two limb vectors of the same length > 0 and
# store difference in a third limb vector.
# Copyright (C) 1995 Free Software Foundation, Inc.
@@ -29,9 +29,9 @@
.text
.align 2
- .globl __mpn_sub_n
- .ent __mpn_sub_n
-__mpn_sub_n:
+ .globl __gmpn_sub_n
+ .ent __gmpn_sub_n
+__gmpn_sub_n:
.set noreorder
.set nomacro
@@ -117,4 +117,4 @@ __mpn_sub_n:
j $31
or $2,$2,$8
- .end __mpn_sub_n
+ .end __gmpn_sub_n
@@ -1,4 +1,4 @@
- # MIPS3 __mpn_sub_n -- Subtract two limb vectors of the same length > 0 and
+ # MIPS3 __gmpn_sub_n -- Subtract two limb vectors of the same length > 0 and
# store difference in a third limb vector.
# Copyright (C) 1995 Free Software Foundation, Inc.
diff --git a/mpn/mips3/submul_1.s b/mpn/mips3/submul_1.s
index a9c9fa251..bfd93b2ef 100644
--- a/mpn/mips3/submul_1.s
+++ b/mpn/mips3/submul_1.s
@@ -1,4 +1,4 @@
# MIPS3 __mpn_submul_1 -- Multiply a limb vector with a single limb and
# subtract the product from a second limb vector.
# Copyright (C) 1992, 1994, 1995 Free Software Foundation, Inc.
@@ -29,9 +29,9 @@
.text
.align 4
- .globl __mpn_submul_1
- .ent __mpn_submul_1
-__mpn_submul_1:
+ .globl __gmpn_submul_1
+ .ent __gmpn_submul_1
+__gmpn_submul_1:
.set noreorder
.set nomacro
@@ -94,4 +94,4 @@ $LC0: ld $10,0($4)
j $31
daddu $2,$9,$2 # add high product limb and carry from addition
- .end __mpn_submul_1
+ .end __gmpn_submul_1
@@ -1,4 +1,4 @@
- # MIPS3 __mpn_submul_1 -- Multiply a limb vector with a single limb and
+ # MIPS3 __gmpn_submul_1 -- Multiply a limb vector with a single limb and
# subtract the product from a second limb vector.
# Copyright (C) 1992, 1994, 1995 Free Software Foundation, Inc.